@@ -82,7 +82,7 @@ impl Emulator {
 
 		// I really don't want to add this,
 		// But tmux and ConPTY sometimes cause the cursor position to get out of sync.
-		if *TMUX || cfg!(windows) {
+		if *TMUX != 0 || cfg!(windows) {
 			execute!(buf, SavePosition, MoveTo(x, y), Show)?;
 			execute!(buf, MoveTo(x, y), Show)?;
 			execute!(buf, MoveTo(x, y), Show)?;
@@ -92,7 +92,7 @@ impl Emulator {
 		}
 
 		let result = cb(&mut buf);
-		if *TMUX || cfg!(windows) {
+		if *TMUX != 0 || cfg!(windows) {
 			queue!(buf, Hide, RestorePosition)?;
 		} else {
 			queue!(buf, RestorePosition)?;
@@ -136,9 +136,9 @@ impl Emulator {
 
 		execute!(
 			LineWriter::new(stderr()),
-			Print("\x1b[16t"),          // Request cell size
-			Print("\x1b]11;?\x07"),     // Request background color
-			Print(Mux::csi("\x1b[0c")), // Request device attributes
+			Print("\x1b[16t"),      // Request cell size
+			Print("\x1b]11;?\x07"), // Request background color
+			Print("\x1b[0c"),       // Request device attributes
 		)?;
 
 		let resp = futures::executor::block_on(Self::read_until_da1());
