@@ -1,9 +1,11 @@
 use std::str::FromStr;
 
+use anyhow::Context;
 use serde::{Deserialize, Serialize};
 use validator::Validate;
+use yazi_fs::SortBy;
 
-use super::{ManagerRatio, MouseEvents, SortBy};
+use super::{ManagerRatio, MouseEvents};
 
 #[derive(Debug, Deserialize, Serialize, Validate)]
 pub struct Manager {
@@ -35,9 +37,10 @@ impl FromStr for Manager {
 			manager: Manager,
 		}
 
-		let manager = toml::from_str::<Outer>(s)?.manager;
-		manager.validate()?;
+		let outer = toml::from_str::<Outer>(s)
+			.context("Failed to parse the [manager] section in your yazi.toml")?;
+		outer.manager.validate()?;
 
-		Ok(manager)
+		Ok(outer.manager)
 	}
 }
