@@ -1,7 +1,7 @@
 use std::path::Path;
 
 use serde::Deserialize;
-use yazi_shared::{event::Cmd, Condition, MIME_DIR};
+use yazi_shared::{Condition, MIME_DIR, event::Cmd};
 
 use crate::{Pattern, Priority};
 
@@ -28,16 +28,3 @@ impl Fetcher {
 				|| self.name.as_ref().is_some_and(|p| p.match_path(path, mime == MIME_DIR)))
 	}
 }
-
-#[derive(Debug, Clone)]
-pub struct FetcherProps {
-	pub id:   u8,
-	pub name: String,
-	pub prio: Priority,
-}
-
-impl From<&Fetcher> for FetcherProps {
-	fn from(fetcher: &Fetcher) -> Self {
-		Self { id: fetcher.idx, name: fetcher.run.name.to_owned(), prio: fetcher.prio }
-	}
-}
