@@ -1,5 +1,6 @@
 use std::str::FromStr;
 
+use anyhow::Context;
 use serde::Deserialize;
 
 use super::{Offset, Origin};
@@ -30,7 +31,7 @@ pub struct Confirm {
 }
 
 impl FromStr for Confirm {
-	type Err = toml::de::Error;
+	type Err = anyhow::Error;
 
 	fn from_str(s: &str) -> Result<Self, Self::Err> {
 		#[derive(Deserialize)]
@@ -38,7 +39,10 @@ impl FromStr for Confirm {
 			confirm: Confirm,
 		}
 
-		Ok(toml::from_str::<Outer>(s)?.confirm)
+		let outer = toml::from_str::<Outer>(s)
+			.context("Failed to parse the [confirm] section in your yazi.toml")?;
+
+		Ok(outer.confirm)
 	}
 }
 
