@@ -1,16 +1,26 @@
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::completion::Completion;
 
-pub struct Opt {
+struct Opt {
 	step: isize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 
 impl Completion {
+	#[yazi_codegen::command]
+	pub fn arrow(&mut self, opt: Opt) {
+		if opt.step > 0 {
+			self.next(opt.step as usize);
+		} else {
+			self.prev(opt.step.unsigned_abs());
+		}
+	}
+
 	fn next(&mut self, step: usize) {
 		let len = self.cands.len();
 		if len == 0 {
@@ -38,13 +48,4 @@ impl Completion {
 
 		render!(old != self.cursor);
 	}
-
-	pub fn arrow(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
-		if opt.step > 0 {
-			self.next(opt.step as usize);
-		} else {
-			self.prev(opt.step.unsigned_abs());
-		}
-	}
 }
