@@ -1,16 +1,26 @@
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_macro::render;
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::{confirm::Confirm, manager::Manager};
 
-pub struct Opt {
+struct Opt {
 	step: isize,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { step: c.first().and_then(Data::as_isize).unwrap_or(0) } }
 }
 
 impl Confirm {
+	#[yazi_codegen::command]
+	pub fn arrow(&mut self, opt: Opt, manager: &Manager) {
+		if opt.step > 0 {
+			self.next(opt.step as usize, manager.area(self.position).width)
+		} else {
+			self.prev(opt.step.unsigned_abs())
+		}
+	}
+
 	fn next(&mut self, step: usize, width: u16) {
 		let height = self.list.line_count(width);
 		if height == 0 {
@@ -29,13 +39,4 @@ impl Confirm {
 
 		render!(old != self.offset);
 	}
-
-	pub fn arrow(&mut self, opt: impl Into<Opt>, manager: &Manager) {
-		let opt = opt.into() as Opt;
-		if opt.step > 0 {
-			self.next(opt.step as usize, manager.area(self.position).width)
-		} else {
-			self.prev(opt.step.unsigned_abs())
-		}
-	}
 }
