@@ -1,6 +1,7 @@
 use tokio::sync::oneshot;
 use yazi_config::popup::ConfirmCfg;
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::confirm::Confirm;
 
@@ -9,10 +10,10 @@ pub struct Opt {
 	tx:  oneshot::Sender<bool>,
 }
 
-impl TryFrom<Cmd> for Opt {
+impl TryFrom<CmdCow> for Opt {
 	type Error = ();
 
-	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
+	fn try_from(mut c: CmdCow) -> Result<Self, Self::Error> {
 		Ok(Self { cfg: c.take_any("cfg").ok_or(())?, tx: c.take_any("tx").ok_or(())? })
 	}
 }
