@@ -1,29 +1,26 @@
-use yazi_shared::{event::Cmd, render};
+use yazi_macro::render;
+use yazi_shared::event::CmdCow;
 
 use crate::input::Input;
 
-pub struct Opt {
+struct Opt {
 	under: bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self { Self { under: c.bool("under") } }
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self { Self { under: c.bool("under") } }
 }
 impl From<bool> for Opt {
 	fn from(under: bool) -> Self { Self { under } }
 }
 
 impl Input {
-	pub fn backspace(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn backspace(&mut self, opt: Opt) {
 		let snap = self.snaps.current_mut();
-		if snap.value.is_empty() {
-			return self.close(false);
-		}
-
-		let opt = opt.into() as Opt;
 		if !opt.under && snap.cursor < 1 {
 			return;
-		} else if opt.under && snap.cursor >= snap.value.len() {
+		} else if opt.under && snap.cursor >= snap.count() {
 			return;
 		}
 
