@@ -1,19 +1,21 @@
+use yazi_macro::render;
 use yazi_proxy::CompletionProxy;
-use yazi_shared::{event::Cmd, render};
+use yazi_shared::event::CmdCow;
 
-use crate::input::{op::InputOp, Input, InputMode};
+use crate::input::{Input, InputMode, op::InputOp};
 
-pub struct Opt;
+struct Opt;
 
-impl From<Cmd> for Opt {
-	fn from(_: Cmd) -> Self { Self }
+impl From<CmdCow> for Opt {
+	fn from(_: CmdCow) -> Self { Self }
 }
 impl From<()> for Opt {
 	fn from(_: ()) -> Self { Self }
 }
 
 impl Input {
-	pub fn escape(&mut self, _: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn escape(&mut self, _: Opt) {
 		let snap = self.snap_mut();
 		match snap.mode {
 			InputMode::Normal if snap.op == InputOp::None => {
