@@ -2,36 +2,37 @@ use std::{borrow::Cow, ffi::OsString};
 
 use tracing::error;
 use yazi_boot::ARGS;
-use yazi_config::{popup::SelectCfg, OPEN};
-use yazi_fs::Folder;
+use yazi_config::{OPEN, PLUGIN, popup::PickCfg};
+use yazi_fs::File;
+use yazi_macro::emit;
 use yazi_plugin::isolate;
-use yazi_proxy::{options::OpenDoOpt, ManagerProxy, TasksProxy};
-use yazi_shared::{emit, event::{Cmd, EventQuit}, fs::{File, Url}, MIME_DIR};
+use yazi_proxy::{ManagerProxy, TasksProxy, options::OpenDoOpt};
+use yazi_shared::{MIME_DIR, event::{CmdCow, EventQuit}, url::Url};
 
-use crate::{manager::Manager, tasks::Tasks};
+use crate::{manager::Manager, tab::Folder, tasks::Tasks};
 
 #[derive(Clone, Copy)]
-pub struct Opt {
+struct Opt {
 	interactive: bool,
 	hovered:     bool,
 }
 
-impl From<Cmd> for Opt {
-	fn from(c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self {
 		Self { interactive: c.bool("interactive"), hovered: c.bool("hovered") }
 	}
 }
 
 impl Manager {
-	pub fn open(&mut self, opt: impl Into<Opt>, tasks: &Tasks) {
+	#[yazi_codegen::command]
+	pub fn open(&mut self, opt: Opt, tasks: &Tasks) {
 		if !self.active_mut().try_escape_visual() {
 			return;
 		}
-		let Some(hovered) = self.hovered().map(|h| h.url()) else {
+		let Some(hovered) = self.hovered().map(|h| h.url_owned()) else {
 			return;
 		};
 
-		let opt = opt.into() as Opt;
 		let selected =
 			if opt.hovered { vec![&hovered] } else { self.selected_or_hovered(true).collect() };
 
@@ -41,10 +42,10 @@ impl Manager {
 
 		let (mut done, mut todo) = (Vec::with_capacity(selected.len()), vec![]);
 		for u in selected {
-			if self.mimetype.contains_key(u) {
-				done.push((u.clone(), String::new()));
+			if self.mimetype.contains(u) {
+				done.push((u.clone(), Cow::Borrowed("")));
 			} else if self.guess_folder(u) {
-				done.push((u.clone(), MIME_DIR.to_owned()));
+				done.push((u.clone(), Cow::Borrowed(MIME_DIR)));
 			} else {
 				todo.push(u.clone());
 			}
@@ -63,22 +64,24 @@ impl Manager {
 				}
 			}
 
-			done.extend(files.iter().map(|f| (f.url(), String::new())));
-			if let Err(e) = isolate::fetch("mime", files).await {
-				error!("Fetch `mime` failed in opening: {e}");
+			done.extend(files.iter().map(|f| (f.url_owned(), Cow::Borrowed(""))));
+			for (fetcher, files) in PLUGIN.mime_fetchers(files) {
+				if let Err(e) = isolate::fetch(CmdCow::from(&fetcher.run), files).await {
+					error!("Fetch mime failed on opening: {e}");
+				}
 			}
 
 			ManagerProxy::open_do(OpenDoOpt { hovered, targets: done, interactive: opt.interactive });
 		});
 	}
 
-	pub fn open_do(&mut self, opt: impl Into<OpenDoOpt>, tasks: &Tasks) {
-		let opt = opt.into() as OpenDoOpt;
+	#[yazi_codegen::command]
+	pub fn open_do(&mut self, opt: OpenDoOpt, tasks: &Tasks) {
 		let targets: Vec<_> = opt
 			.targets
 			.into_iter()
 			.filter_map(|(u, m)| {
-				Some(m).filter(|m| !m.is_empty()).or_else(|| self.mimetype.get(&u).cloned()).map(|m| (u, m))
+				Some(m).filter(|m| !m.is_empty()).or_else(|| self.mimetype.by_url_owned(&u)).map(|m| (u, m))
 			})
 			.collect();
 
@@ -95,7 +98,7 @@ impl Manager {
 
 		let urls = [opt.hovered].into_iter().chain(targets.into_iter().map(|(u, _)| u)).collect();
 		tokio::spawn(async move {
-			let result = yazi_proxy::SelectProxy::show(SelectCfg::open(
+			let result = yazi_proxy::PickProxy::show(PickCfg::open(
 				openers.iter().map(|o| o.desc.clone()).collect(),
 			));
 			if let Ok(choice) = result.await {
@@ -111,7 +114,7 @@ impl Manager {
 
 		let find = |folder: Option<&Folder>| {
 			folder.is_some_and(|folder| {
-				folder.cwd == p && folder.files.iter().any(|f| f.is_dir() && f.url == *url)
+				p == folder.url && folder.files.iter().any(|f| f.is_dir() && f.urn() == url.urn())
 			})
 		};
 
