@@ -1,16 +1,15 @@
-use std::{env, path::MAIN_SEPARATOR};
+use std::path::MAIN_SEPARATOR;
 
 use crossterm::{execute, terminal::SetTitle};
 use yazi_config::MANAGER;
-use yazi_shared::event::Cmd;
+use yazi_fs::CWD;
+use yazi_shared::event::CmdCow;
 
 use crate::{manager::Manager, tasks::Tasks};
 
 impl Manager {
-	pub fn refresh(&mut self, _: Cmd, tasks: &Tasks) {
-		env::set_current_dir(self.cwd()).ok();
-		env::set_var("PWD", self.cwd());
-
+	pub fn refresh(&mut self, _: CmdCow, tasks: &Tasks) {
+		CWD.set(self.cwd());
 		if !MANAGER.title_format.is_empty() {
 			execute!(std::io::stderr(), SetTitle(self.title())).ok();
 		}
@@ -31,7 +30,7 @@ impl Manager {
 
 	fn title(&self) -> String {
 		let home = dirs::home_dir().unwrap_or_default();
-		let cwd = if let Some(p) = self.cwd().strip_prefix(home) {
+		let cwd = if let Ok(p) = self.cwd().strip_prefix(home) {
 			format!("~{}{}", MAIN_SEPARATOR, p.display())
 		} else {
 			format!("{}", self.cwd().display())
