@@ -1,23 +1,24 @@
-use std::collections::HashMap;
+use std::{borrow::Cow, collections::{HashMap, HashSet}};
 
 use anyhow::Result;
 use tokio::fs;
 use yazi_config::popup::{ConfirmCfg, InputCfg};
 use yazi_dds::Pubsub;
+use yazi_fs::{File, FilesOp, maybe_exists, ok_or_not_found, paths_to_same_file, realname};
 use yazi_proxy::{ConfirmProxy, InputProxy, TabProxy, WATCHER};
-use yazi_shared::{event::Cmd, fs::{maybe_exists, ok_or_not_found, paths_to_same_file, symlink_realpath, File, FilesOp, Url}};
+use yazi_shared::{Id, event::CmdCow, url::{Url, UrnBuf}};
 
 use crate::manager::Manager;
 
-pub struct Opt {
+struct Opt {
 	hovered: bool,
 	force:   bool,
-	empty:   String,
-	cursor:  String,
+	empty:   Cow<'static, str>,
+	cursor:  Cow<'static, str>,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
 		Self {
 			hovered: c.bool("hovered"),
 			force:   c.bool("force"),
@@ -28,21 +29,21 @@ impl From<Cmd> for Opt {
 }
 
 impl Manager {
-	pub fn rename(&mut self, opt: impl Into<Opt>) {
+	#[yazi_codegen::command]
+	pub fn rename(&mut self, opt: Opt) {
 		if !self.active_mut().try_escape_visual() {
 			return;
 		}
-		let Some(hovered) = self.hovered().map(|h| h.url()) else {
+		let Some(hovered) = self.hovered().map(|h| h.url_owned()) else {
 			return;
 		};
 
-		let opt = opt.into() as Opt;
 		if !opt.hovered && !self.active().selected.is_empty() {
 			return self.bulk_rename();
 		}
 
 		let name = Self::empty_url_part(&hovered, &opt.empty);
-		let cursor = match opt.cursor.as_str() {
+		let cursor = match opt.cursor.as_ref() {
 			"start" => Some(0),
 			"before_ext" => name
 				.chars()
@@ -53,7 +54,7 @@ impl Manager {
 			_ => None,
 		};
 
-		let tab = self.tabs.cursor;
+		let tab = self.tabs.active().id;
 		tokio::spawn(async move {
 			let mut result = InputProxy::show(InputCfg::rename().with_value(name).with_cursor(cursor));
 			let Some(Ok(name)) = result.recv().await else {
@@ -73,23 +74,28 @@ impl Manager {
 		});
 	}
 
-	async fn rename_do(tab: usize, old: Url, new: Url) -> Result<()> {
-		let Some(p_old) = old.parent_url() else { return Ok(()) };
-		let Some(p_new) = new.parent_url() else { return Ok(()) };
+	async fn rename_do(tab: Id, old: Url, new: Url) -> Result<()> {
+		let Some((p_old, n_old)) = old.pair() else { return Ok(()) };
+		let Some((p_new, n_new)) = new.pair() else { return Ok(()) };
 		let _permit = WATCHER.acquire().await.unwrap();
 
-		let overwritten = symlink_realpath(&new).await;
+		let overwritten = realname(&new).await;
 		fs::rename(&old, &new).await?;
 
-		if let Ok(o) = overwritten {
-			ok_or_not_found(fs::rename(&o, &new).await)?;
-			FilesOp::Deleting(p_new.clone(), vec![Url::from(o)]).emit();
+		if let Some(o) = overwritten {
+			ok_or_not_found(fs::rename(p_new.join(&o), &new).await)?;
+			FilesOp::Deleting(p_new.clone(), HashSet::from_iter([UrnBuf::from(o)])).emit();
 		}
 		Pubsub::pub_from_rename(tab, &old, &new);
 
 		let file = File::from(new.clone()).await?;
-		FilesOp::Deleting(p_old, vec![old]).emit();
-		FilesOp::Upserting(p_new, HashMap::from_iter([(new.clone(), file)])).emit();
+		if p_new == p_old {
+			FilesOp::Upserting(p_old, HashMap::from_iter([(n_old, file)])).emit();
+		} else {
+			FilesOp::Deleting(p_old, HashSet::from_iter([n_old])).emit();
+			FilesOp::Upserting(p_new, HashMap::from_iter([(n_new, file)])).emit();
+		}
+
 		Ok(TabProxy::reveal(&new))
 	}
 
@@ -100,10 +106,10 @@ impl Manager {
 
 		let ext = url.extension();
 		match by {
-			"stem" => ext.map_or_else(String::new, |s| format!(".{}", s.to_string_lossy().into_owned())),
+			"stem" => ext.map_or_else(String::new, |s| format!(".{}", s.to_string_lossy())),
 			"ext" if ext.is_some() => format!("{}.", url.file_stem().unwrap().to_string_lossy()),
 			"dot_ext" if ext.is_some() => url.file_stem().unwrap().to_string_lossy().into_owned(),
-			_ => url.file_name().map_or_else(String::new, |s| s.to_string_lossy().into_owned()),
+			_ => url.name().to_string_lossy().into_owned(),
 		}
 	}
 }
