@@ -1,19 +1,20 @@
 use std::borrow::Cow;
 
-use yazi_fs::Folder;
+use yazi_fs::FilesOp;
+use yazi_macro::render;
 use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::Cmd, fs::FilesOp, render};
+use yazi_shared::event::CmdCow;
 
-use crate::{manager::{Manager, LINKED}, tab::Tab, tasks::Tasks};
+use crate::{manager::{LINKED, Manager}, tab::{Folder, Tab}, tasks::Tasks};
 
 pub struct Opt {
 	op: FilesOp,
 }
 
-impl TryFrom<Cmd> for Opt {
+impl TryFrom<CmdCow> for Opt {
 	type Error = ();
 
-	fn try_from(mut c: Cmd) -> Result<Self, Self::Error> {
+	fn try_from(mut c: CmdCow) -> Result<Self, Self::Error> {
 		Ok(Self { op: c.take_any("op").ok_or(())? })
 	}
 }
@@ -24,12 +25,8 @@ impl Manager {
 			return;
 		};
 
-		let mut ops = vec![opt.op];
-		for u in LINKED.read().from_dir(ops[0].url()) {
-			ops.push(ops[0].chroot(u));
-		}
-
-		for op in ops {
+		let linked: Vec<_> = LINKED.read().from_dir(opt.op.cwd()).map(|u| opt.op.rebase(u)).collect();
+		for op in [opt.op].into_iter().chain(linked) {
 			let idx = self.tabs.cursor;
 			self.yanked.apply_op(&op);
 
@@ -44,14 +41,14 @@ impl Manager {
 	}
 
 	fn update_tab(tab: &mut Tab, op: Cow<FilesOp>, tasks: &Tasks) {
-		let url = op.url();
+		let url = op.cwd();
 		tab.selected.apply_op(&op);
 
-		if tab.current.cwd == *url {
+		if url == tab.cwd() {
 			Self::update_current(tab, op, tasks);
-		} else if matches!(&tab.parent, Some(p) if p.cwd == *url) {
+		} else if matches!(&tab.parent, Some(p) if *url == p.url) {
 			Self::update_parent(tab, op);
-		} else if matches!(tab.current.hovered(), Some(h) if h.url == *url) {
+		} else if matches!(tab.hovered(), Some(h) if *url == h.url) {
 			Self::update_hovered(tab, op);
 		} else {
 			Self::update_history(tab, op);
@@ -59,12 +56,12 @@ impl Manager {
 	}
 
 	fn update_parent(tab: &mut Tab, op: Cow<FilesOp>) {
-		let cwd = tab.current.cwd.clone();
-		let leave = matches!(*op, FilesOp::Deleting(_, ref urls) if urls.contains(&cwd));
+		let urn = tab.cwd().urn_owned();
+		let leave = matches!(*op, FilesOp::Deleting(_, ref urns) if urns.contains(&urn));
 
 		if let Some(f) = tab.parent.as_mut() {
-			render!(f.update(op.into_owned()));
-			render!(f.hover(&cwd));
+			render!(f.update_pub(tab.id, op.into_owned()));
+			render!(f.hover(urn.as_urn()));
 		}
 
 		if leave {
@@ -73,20 +70,20 @@ impl Manager {
 	}
 
 	fn update_current(tab: &mut Tab, op: Cow<FilesOp>, tasks: &Tasks) {
-		let hovered = tab.current.hovered().filter(|_| tab.current.tracing).map(|h| h.url());
+		let hovered = tab.hovered().filter(|_| tab.current.tracing).map(|h| h.urn_owned());
 		let calc = !matches!(*op, FilesOp::Size(..) | FilesOp::Deleting(..));
 
 		let foreign = matches!(op, Cow::Borrowed(_));
-		if !tab.current.update(op.into_owned()) {
+		if !tab.current.update_pub(tab.id, op.into_owned()) {
 			return;
 		}
 
-		tab.current.repos(hovered);
+		tab.current.repos(hovered.as_ref().map(|u| u.as_urn()));
 		if foreign {
 			return;
 		}
 
-		ManagerProxy::hover(None, tab.idx); // Re-hover in next loop
+		ManagerProxy::hover(None, tab.id); // Re-hover in next loop
 		ManagerProxy::update_paged(); // Update for paged files in next loop
 		if calc {
 			tasks.prework_sorted(&tab.current.files);
@@ -94,11 +91,11 @@ impl Manager {
 	}
 
 	fn update_hovered(tab: &mut Tab, op: Cow<FilesOp>) {
-		let url = op.url();
+		let url = op.cwd();
 		let folder = tab.history.entry(url.clone()).or_insert_with(|| Folder::from(url));
 
 		let foreign = matches!(op, Cow::Borrowed(_));
-		if !folder.update(op.into_owned()) {
+		if !folder.update_pub(tab.id, op.into_owned()) {
 			return;
 		}
 
@@ -108,14 +105,14 @@ impl Manager {
 	}
 
 	fn update_history(tab: &mut Tab, op: Cow<FilesOp>) {
-		let leave = tab.parent.as_ref().and_then(|f| f.cwd.parent_url().map(|p| (&f.cwd, p))).is_some_and(
-			|(p, pp)| matches!(*op, FilesOp::Deleting(ref parent, ref urls) if *parent == pp && urls.contains(p)),
+		let leave = tab.parent.as_ref().and_then(|f| f.url.parent_url().map(|p| (p, f.url.urn()))).is_some_and(
+			|(p, n)| matches!(*op, FilesOp::Deleting(ref parent, ref urns) if *parent == p && urns.contains(n)),
 		);
 
-		let folder = tab.history.entry(op.url().clone()).or_insert_with(|| Folder::from(op.url()));
-		let hovered = folder.hovered().filter(|_| folder.tracing).map(|h| h.url());
-		if folder.update(op.into_owned()) {
-			folder.repos(hovered);
+		let folder = tab.history.entry(op.cwd().clone()).or_insert_with(|| Folder::from(op.cwd()));
+		let hovered = folder.hovered().filter(|_| folder.tracing).map(|h| h.urn_owned());
+		if folder.update_pub(tab.id, op.into_owned()) {
+			folder.repos(hovered.as_ref().map(|u| u.as_urn()));
 		}
 
 		if leave {
