@@ -1,4 +1,4 @@
-use yazi_shared::{event::{Cmd, Data}, fs::Url};
+use yazi_shared::{event::{CmdCow, Data}, url::Url};
 
 use crate::{manager::Manager, tasks::Tasks};
 
@@ -8,12 +8,9 @@ pub struct Opt {
 	only_if: Option<Url>,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		Self {
-			page:    c.first().and_then(Data::as_usize),
-			only_if: c.take("only-if").and_then(Data::into_url),
-		}
+impl From<CmdCow> for Opt {
+	fn from(mut c: CmdCow) -> Self {
+		Self { page: c.first().and_then(Data::as_usize), only_if: c.take_url("only-if") }
 	}
 }
 
@@ -27,7 +24,7 @@ impl Manager {
 			return;
 		};
 
-		if opt.only_if.is_some_and(|u| u != self.current().cwd) {
+		if opt.only_if.is_some_and(|u| u != *self.cwd()) {
 			return;
 		}
 
