@@ -1,20 +1,18 @@
-use std::collections::HashMap;
-
 use ratatui::layout::Rect;
 use yazi_adapter::Dimension;
 use yazi_config::popup::{Origin, Position};
-use yazi_fs::Folder;
-use yazi_shared::fs::{File, Url};
+use yazi_fs::File;
+use yazi_shared::{Id, url::Url};
 
-use super::{Tabs, Watcher, Yanked};
-use crate::tab::Tab;
+use super::{Mimetype, Tabs, Watcher, Yanked};
+use crate::tab::{Folder, Tab};
 
 pub struct Manager {
 	pub tabs:   Tabs,
 	pub yanked: Yanked,
 
 	pub(super) watcher: Watcher,
-	pub mimetype:       HashMap<Url, String>,
+	pub mimetype:       Mimetype,
 }
 
 impl Manager {
@@ -41,7 +39,7 @@ impl Manager {
 
 impl Manager {
 	#[inline]
-	pub fn cwd(&self) -> &Url { &self.current().cwd }
+	pub fn cwd(&self) -> &Url { self.active().cwd() }
 
 	#[inline]
 	pub fn active(&self) -> &Tab { self.tabs.active() }
@@ -50,10 +48,10 @@ impl Manager {
 	pub fn active_mut(&mut self) -> &mut Tab { self.tabs.active_mut() }
 
 	#[inline]
-	pub fn active_or(&self, idx: Option<usize>) -> &Tab { self.tabs.active_or(idx) }
+	pub fn active_or(&self, id: Option<Id>) -> &Tab { self.tabs.active_or(id) }
 
 	#[inline]
-	pub fn active_or_mut(&mut self, idx: Option<usize>) -> &mut Tab { self.tabs.active_or_mut(idx) }
+	pub fn active_or_mut(&mut self, id: Option<Id>) -> &mut Tab { self.tabs.active_or_mut(id) }
 
 	#[inline]
 	pub fn current(&self) -> &Folder { &self.active().current }
@@ -62,18 +60,18 @@ impl Manager {
 	pub fn current_mut(&mut self) -> &mut Folder { &mut self.active_mut().current }
 
 	#[inline]
-	pub fn current_or(&self, idx: Option<usize>) -> &Folder { &self.active_or(idx).current }
+	pub fn current_or(&self, id: Option<Id>) -> &Folder { &self.active_or(id).current }
 
 	#[inline]
-	pub fn current_or_mut(&mut self, idx: Option<usize>) -> &mut Folder {
-		&mut self.active_or_mut(idx).current
+	pub fn current_or_mut(&mut self, id: Option<Id>) -> &mut Folder {
+		&mut self.active_or_mut(id).current
 	}
 
 	#[inline]
 	pub fn parent(&self) -> Option<&Folder> { self.active().parent.as_ref() }
 
 	#[inline]
-	pub fn hovered(&self) -> Option<&File> { self.active().current.hovered() }
+	pub fn hovered(&self) -> Option<&File> { self.active().hovered() }
 
 	#[inline]
 	pub fn hovered_folder(&self) -> Option<&Folder> { self.active().hovered_folder() }
