@@ -1,17 +1,18 @@
 use yazi_fs::Step;
+use yazi_macro::render;
 use yazi_proxy::ManagerProxy;
-use yazi_shared::{event::{Cmd, Data}, render};
+use yazi_shared::event::{CmdCow, Data};
 
 use crate::tab::Tab;
 
-pub struct Opt {
+struct Opt {
 	step: Step,
 }
 
-impl From<Cmd> for Opt {
-	fn from(mut c: Cmd) -> Self {
-		let step = match c.take_first() {
-			Some(Data::Integer(i)) => Step::from(i as isize),
+impl From<CmdCow> for Opt {
+	fn from(c: CmdCow) -> Self {
+		let step = match c.first() {
+			Some(Data::Integer(i)) => Step::from(*i as isize),
 			Some(Data::String(s)) => s.parse().unwrap_or_default(),
 			_ => Step::default(),
 		};
@@ -25,8 +26,8 @@ impl From<isize> for Opt {
 }
 
 impl Tab {
-	pub fn arrow(&mut self, opt: impl Into<Opt>) {
-		let opt = opt.into() as Opt;
+	#[yazi_codegen::command]
+	pub fn arrow(&mut self, opt: Opt) {
 		if !self.current.arrow(opt.step) {
 			return;
 		}
@@ -41,7 +42,7 @@ impl Tab {
 			}
 		}
 
-		ManagerProxy::hover(None, self.idx);
+		ManagerProxy::hover(None, self.id);
 		render!();
 	}
 }
