@@ -1,12 +1,13 @@
-use std::{collections::VecDeque, sync::atomic::Ordering};
+use std::sync::atomic::Ordering;
 
 use anyhow::Result;
 use crossterm::event::KeyEvent;
 use yazi_config::keymap::Key;
 use yazi_core::input::InputMode;
-use yazi_shared::{emit, event::{Cmd, Event, NEED_RENDER}, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::{CmdCow, Event, NEED_RENDER}};
 
-use crate::{lives::Lives, Ctx, Executor, Router, Signals, Term};
+use crate::{Ctx, Executor, Router, Signals, Term, lives::Lives};
 
 pub(crate) struct App {
 	pub(crate) cx:      Ctx,
@@ -65,12 +66,14 @@ impl App {
 	}
 
 	#[inline]
-	fn dispatch_call(&mut self, cmd: Cmd, layer: Layer) { Executor::new(self).execute(cmd, layer); }
+	fn dispatch_call(&mut self, cmd: CmdCow, layer: Layer) {
+		Executor::new(self).execute(cmd, layer);
+	}
 
 	#[inline]
-	fn dispatch_seq(&mut self, mut cmds: VecDeque<Cmd>, layer: Layer) {
-		if let Some(cmd) = cmds.pop_front() {
-			Executor::new(self).execute(cmd, layer);
+	fn dispatch_seq(&mut self, mut cmds: Vec<CmdCow>, layer: Layer) {
+		if let Some(last) = cmds.pop() {
+			Executor::new(self).execute(last, layer);
 		}
 		if !cmds.is_empty() {
 			emit!(Seq(cmds, layer));
