@@ -1,10 +1,10 @@
 use ratatui::layout::Rect;
-use yazi_core::{completion::Completion, confirm::Confirm, help::Help, input::Input, manager::Manager, notify::Notify, select::Select, tasks::Tasks, which::Which};
+use yazi_core::{completion::Completion, confirm::Confirm, help::Help, input::Input, manager::Manager, notify::Notify, pick::Pick, tab::{Folder, Tab}, tasks::Tasks, which::Which};
 
 pub struct Ctx {
 	pub manager:    Manager,
 	pub tasks:      Tasks,
-	pub select:     Select,
+	pub pick:       Pick,
 	pub input:      Input,
 	pub confirm:    Confirm,
 	pub help:       Help,
@@ -18,7 +18,7 @@ impl Ctx {
 		Self {
 			manager:    Manager::make(),
 			tasks:      Tasks::serve(),
-			select:     Default::default(),
+			pick:       Default::default(),
 			input:      Default::default(),
 			confirm:    Default::default(),
 			help:       Default::default(),
@@ -40,3 +40,17 @@ impl Ctx {
 		None
 	}
 }
+
+impl Ctx {
+	#[inline]
+	pub fn active(&self) -> &Tab { self.manager.active() }
+
+	#[inline]
+	pub fn active_mut(&mut self) -> &mut Tab { self.manager.active_mut() }
+
+	#[inline]
+	pub fn current(&self) -> &Folder { self.manager.current() }
+
+	#[inline]
+	pub fn current_mut(&mut self) -> &mut Folder { self.manager.current_mut() }
+}
