@@ -5,48 +5,24 @@
 #[global_allocator]
 static GLOBAL: tikv_jemallocator::Jemalloc = tikv_jemallocator::Jemalloc;
 
-mod app;
-mod completion;
-mod components;
-mod confirm;
-mod context;
-mod executor;
-mod help;
-mod input;
-mod lives;
-mod logs;
-mod notify;
-mod panic;
-mod root;
-mod router;
-mod select;
-mod signals;
-mod tasks;
-mod term;
-mod which;
+yazi_macro::mod_pub!(app completion confirm help input lives manager notify pick spot tasks which);
 
-use context::*;
-use executor::*;
-use logs::*;
-use panic::*;
-#[allow(unused_imports)]
-use root::*;
-use router::*;
-use signals::*;
-use term::*;
+yazi_macro::mod_flat!(context executor logs panic root router signals term);
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
 	Panic::install();
-	Logs::start();
+	Logs::start()?;
 
 	_ = fdlimit::raise_fd_limit();
 
 	yazi_shared::init();
 
+	yazi_fs::init();
+
 	yazi_config::init()?;
 
-	yazi_adapter::init();
+	yazi_adapter::init()?;
 
 	yazi_boot::init();
 
