@@ -1,5 +1,6 @@
-use yazi_config::{keymap::{Chord, Key}, KEYMAP};
-use yazi_shared::{emit, Layer};
+use yazi_config::{KEYMAP, keymap::{Chord, ChordCow, Key}};
+use yazi_macro::emit;
+use yazi_shared::Layer;
 
 use crate::app::App;
 
@@ -33,8 +34,10 @@ impl<'a> Router<'a> {
 			self.matches(Layer::Input, key)
 		} else if cx.confirm.visible {
 			self.matches(Layer::Confirm, key)
-		} else if cx.select.visible {
-			self.matches(Layer::Select, key)
+		} else if cx.pick.visible {
+			self.matches(Layer::Pick, key)
+		} else if cx.active().spot.visible() {
+			self.matches(Layer::Spot, key)
 		} else if cx.tasks.visible {
 			self.matches(Layer::Tasks, key)
 		} else {
@@ -44,7 +47,7 @@ impl<'a> Router<'a> {
 
 	#[inline]
 	fn matches(&mut self, layer: Layer, key: Key) -> bool {
-		for ctrl @ Chord { on, .. } in KEYMAP.get(layer) {
+		for chord @ Chord { on, .. } in KEYMAP.get(layer) {
 			if on.is_empty() || on[0] != key {
 				continue;
 			}
@@ -52,7 +55,7 @@ impl<'a> Router<'a> {
 			if on.len() > 1 {
 				self.app.cx.which.show_with(key, layer);
 			} else {
-				emit!(Seq(ctrl.to_seq(), layer));
+				emit!(Seq(ChordCow::from(chord).into_seq(), layer));
 			}
 			return true;
 		}
