@@ -1,10 +1,10 @@
-use std::{io::{self, stderr, BufWriter, Stderr}, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, AtomicU8, Ordering}};
+use std::{io::{self, BufWriter, Stderr, stderr}, ops::{Deref, DerefMut}, sync::atomic::{AtomicBool, AtomicU8, Ordering}};
 
 use anyhow::Result;
-use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{disable_raw_mode, enable_raw_mode, EnterAlternateScreen, LeaveAlternateScreen, SetTitle}};
+use crossterm::{event::{DisableBracketedPaste, EnableBracketedPaste, KeyboardEnhancementFlags, PopKeyboardEnhancementFlags, PushKeyboardEnhancementFlags}, execute, queue, style::Print, terminal::{EnterAlternateScreen, LeaveAlternateScreen, SetTitle, disable_raw_mode, enable_raw_mode}};
 use cursor::RestoreCursor;
-use ratatui::{backend::CrosstermBackend, buffer::Buffer, layout::Rect, CompletedFrame, Frame, Terminal};
-use yazi_adapter::{tcsi, Emulator};
+use ratatui::{CompletedFrame, Frame, Terminal, backend::CrosstermBackend, buffer::Buffer, layout::Rect};
+use yazi_adapter::{Emulator, Mux};
 use yazi_config::{INPUT, MANAGER};
 
 static CSI_U: AtomicBool = AtomicBool::new(false);
@@ -28,10 +28,11 @@ impl Term {
 		enable_raw_mode()?;
 		execute!(
 			BufWriter::new(stderr()),
-			Print(tcsi("\x1b[?12$p")),      // Request cursor blink status (DECSET)
-			Print(tcsi("\x1bP$q q\x1b\\")), // Request cursor shape (DECRQM)
-			Print(tcsi("\x1b[?u\x1b[c")),   // Request keyboard enhancement flags (CSI u)
 			EnterAlternateScreen,
+			Print(Mux::csi("\x1bP$q q\x1b\\")), // Request cursor shape (DECRQM)
+			Print(Mux::csi("\x1b[?12$p")),      // Request cursor blink status (DECSET)
+			Print("\x1b[?u"),                   // Request keyboard enhancement flags (CSI u)
+			Print(Mux::csi("\x1b[0c")),         // Request device attributes
 			EnableBracketedPaste,
 			mouse::SetMouse(true),
 		)?;
