@@ -1,43 +1,26 @@
-use std::{collections::{HashMap, HashSet}, mem, ops::Deref, sync::atomic::Ordering};
+use std::{collections::{HashMap, HashSet}, mem, ops::Deref};
 
 use tokio::{fs::{self, DirEntry}, select, sync::mpsc::{self, UnboundedReceiver}};
-use yazi_config::{manager::SortBy, MANAGER};
-use yazi_shared::fs::{maybe_exists, Cha, File, FilesOp, Url, FILES_TICKET};
+use yazi_shared::{Id, url::{Url, Urn, UrnBuf}};
 
 use super::{FilesSorter, Filter};
+use crate::{Cha, FILES_TICKET, File, FilesOp, SortBy, maybe_exists};
 
+#[derive(Default)]
 pub struct Files {
 	hidden:       Vec<File>,
 	items:        Vec<File>,
-	ticket:       u64,
+	ticket:       Id,
 	version:      u64,
 	pub revision: u64,
 
-	pub sizes: HashMap<Url, u64>,
+	pub sizes: HashMap<UrnBuf, u64>,
 
 	sorter:      FilesSorter,
 	filter:      Option<Filter>,
 	show_hidden: bool,
 }
 
-impl Default for Files {
-	fn default() -> Self {
-		Self {
-			items:    Default::default(),
-			hidden:   Default::default(),
-			ticket:   Default::default(),
-			version:  Default::default(),
-			revision: Default::default(),
-
-			sizes: Default::default(),
-
-			sorter:      Default::default(),
-			filter:      Default::default(),
-			show_hidden: MANAGER.show_hidden,
-		}
-	}
-}
-
 impl Deref for Files {
 	type Target = Vec<File>;
 
@@ -45,8 +28,8 @@ impl Deref for Files {
 }
 
 impl Files {
-	pub async fn from_dir(url: &Url) -> std::io::Result<UnboundedReceiver<File>> {
-		let mut it = fs::read_dir(url).await?;
+	pub async fn from_dir(dir: &Url) -> std::io::Result<UnboundedReceiver<File>> {
+		let mut it = fs::read_dir(dir).await?;
 		let (tx, rx) = mpsc::unbounded_channel();
 
 		tokio::spawn(async move {
@@ -66,18 +49,18 @@ impl Files {
 		Ok(rx)
 	}
 
-	pub async fn from_dir_bulk(url: &Url) -> std::io::Result<Vec<File>> {
-		let mut it = fs::read_dir(url).await?;
-		let mut items = Vec::with_capacity(5000);
-		while let Ok(Some(item)) = it.next_entry().await {
-			items.push(item);
+	pub async fn from_dir_bulk(dir: &Url) -> std::io::Result<Vec<File>> {
+		let mut it = fs::read_dir(dir).await?;
+		let mut entries = Vec::with_capacity(5000);
+		while let Ok(Some(entry)) = it.next_entry().await {
+			entries.push(entry);
 		}
 
-		let (first, rest) = items.split_at(items.len() / 3);
-		let (second, third) = rest.split_at(items.len() / 3);
-		async fn go(entities: &[DirEntry]) -> Vec<File> {
-			let mut files = Vec::with_capacity(entities.len() / 3 + 1);
-			for entry in entities {
+		let (first, rest) = entries.split_at(entries.len() / 3);
+		let (second, third) = rest.split_at(entries.len() / 3);
+		async fn go(entries: &[DirEntry]) -> Vec<File> {
+			let mut files = Vec::with_capacity(entries.len() / 3 + 1);
+			for entry in entries {
 				let url = Url::from(entry.path());
 				files.push(match entry.metadata().await {
 					Ok(meta) => File::from_meta(url, meta).await,
@@ -96,19 +79,19 @@ impl Files {
 		)
 	}
 
-	pub async fn assert_stale(url: &Url, cha: Cha) -> Option<Cha> {
-		match fs::metadata(url).await.map(Cha::from) {
+	pub async fn assert_stale(cwd: &Url, cha: Cha) -> Option<Cha> {
+		match fs::metadata(cwd).await.map(Cha::from) {
 			Ok(c) if !c.is_dir() => {
-				// FIXME: use `ErrorKind::NotADirectory` instead once it gets stabilized
-				FilesOp::IOErr(url.clone(), std::io::ErrorKind::AlreadyExists).emit();
+				// TODO: use `ErrorKind::NotADirectory` instead once it gets stabilized
+				FilesOp::IOErr(cwd.clone(), std::io::ErrorKind::AlreadyExists).emit();
 			}
 			Ok(c) if c.hits(cha) => {}
 			Ok(c) => return Some(c),
 			Err(e) => {
-				if maybe_exists(url).await {
-					FilesOp::IOErr(url.clone(), e.kind()).emit();
-				} else if let Some(p) = url.parent_url() {
-					FilesOp::Deleting(p, vec![url.clone()]).emit();
+				if maybe_exists(cwd).await {
+					FilesOp::IOErr(cwd.clone(), e.kind()).emit();
+				} else if let Some((p, n)) = cwd.pair() {
+					FilesOp::Deleting(p, HashSet::from_iter([n])).emit();
 				}
 			}
 		}
@@ -118,15 +101,17 @@ impl Files {
 
 impl Files {
 	pub fn update_full(&mut self, files: Vec<File>) {
-		self.ticket = FILES_TICKET.fetch_add(1, Ordering::Relaxed);
+		self.ticket = FILES_TICKET.next();
 
-		(self.hidden, self.items) = self.split_files(files);
-		if !self.items.is_empty() {
+		let (hidden, items) = self.split_files(files);
+		if !(items.is_empty() && self.items.is_empty()) {
 			self.revision += 1;
 		}
+
+		(self.hidden, self.items) = (hidden, items);
 	}
 
-	pub fn update_part(&mut self, files: Vec<File>, ticket: u64) {
+	pub fn update_part(&mut self, files: Vec<File>, ticket: Id) {
 		if !files.is_empty() {
 			if ticket != self.ticket {
 				return;
@@ -150,7 +135,7 @@ impl Files {
 		}
 	}
 
-	pub fn update_size(&mut self, sizes: HashMap<Url, u64>) {
+	pub fn update_size(&mut self, sizes: HashMap<UrnBuf, u64>) {
 		if sizes.is_empty() {
 			return;
 		}
@@ -162,7 +147,7 @@ impl Files {
 	}
 
 	pub fn update_ioerr(&mut self) {
-		self.ticket = FILES_TICKET.fetch_add(1, Ordering::Relaxed);
+		self.ticket = FILES_TICKET.next();
 		self.hidden.clear();
 		self.items.clear();
 	}
@@ -174,9 +159,9 @@ impl Files {
 
 		macro_rules! go {
 			($dist:expr, $src:expr, $inc:literal) => {
-				let mut todo: HashMap<_, _> = $src.into_iter().map(|f| (f.url(), f)).collect();
+				let mut todo: HashMap<_, _> = $src.into_iter().map(|f| (f.urn_owned(), f)).collect();
 				for f in &$dist {
-					if todo.remove(&f.url).is_some() && todo.is_empty() {
+					if todo.remove(f.urn()).is_some() && todo.is_empty() {
 						break;
 					}
 				}
@@ -197,31 +182,30 @@ impl Files {
 	}
 
 	#[cfg(unix)]
-	pub fn update_deleting(&mut self, urls: Vec<Url>) {
-		if urls.is_empty() {
+	pub fn update_deleting(&mut self, urns: HashSet<UrnBuf>) {
+		if urns.is_empty() {
 			return;
 		}
 
 		macro_rules! go {
 			($dist:expr, $src:expr, $inc:literal) => {
-				let mut todo: HashSet<_> = $src.into_iter().collect();
 				let len = $dist.len();
-
-				$dist.retain(|f| !todo.remove(&f.url));
+				$dist.retain(|f| !$src.remove(f.urn()));
 				if $dist.len() != len {
 					self.revision += $inc;
 				}
 			};
 		}
 
-		let (hidden, items) = if let Some(filter) = &self.filter {
-			urls.into_iter().partition(|u| {
-				(!self.show_hidden && u.is_hidden()) || !u.file_name().is_some_and(|s| filter.matches(s))
+		let (mut hidden, mut items) = if let Some(filter) = &self.filter {
+			urns.into_iter().partition(|u| {
+				(!self.show_hidden && u.as_urn().is_hidden())
+					|| !u.as_urn().name().is_some_and(|s| filter.matches(s))
 			})
 		} else if self.show_hidden {
-			(vec![], urls)
+			(HashSet::new(), urns)
 		} else {
-			urls.into_iter().partition(|u| u.is_hidden())
+			urns.into_iter().partition(|u| u.as_urn().is_hidden())
 		};
 
 		if !items.is_empty() {
@@ -233,31 +217,29 @@ impl Files {
 	}
 
 	#[cfg(windows)]
-	pub fn update_deleting(&mut self, urls: Vec<Url>) {
+	pub fn update_deleting(&mut self, mut urns: HashSet<UrnBuf>) {
 		macro_rules! go {
 			($dist:expr, $src:expr, $inc:literal) => {
 				let len = $dist.len();
-
-				$dist.retain(|f| !$src.remove(&f.url));
+				$dist.retain(|f| !$src.remove(f.urn()));
 				if $dist.len() != len {
 					self.revision += $inc;
 				}
 			};
 		}
 
-		let mut urls: HashSet<_> = urls.into_iter().collect();
-		if !urls.is_empty() {
-			go!(self.items, urls, 1);
+		if !urns.is_empty() {
+			go!(self.items, urns, 1);
 		}
-		if !urls.is_empty() {
-			go!(self.hidden, urls, 0);
+		if !urns.is_empty() {
+			go!(self.hidden, urns, 0);
 		}
 	}
 
 	pub fn update_updating(
 		&mut self,
-		files: HashMap<Url, File>,
-	) -> (HashMap<Url, File>, HashMap<Url, File>) {
+		files: HashMap<UrnBuf, File>,
+	) -> (HashMap<UrnBuf, File>, HashMap<UrnBuf, File>) {
 		if files.is_empty() {
 			return Default::default();
 		}
@@ -266,10 +248,11 @@ impl Files {
 			($dist:expr, $src:expr, $inc:literal) => {
 				let mut b = true;
 				for i in 0..$dist.len() {
-					if let Some(f) = $src.remove(&$dist[i].url) {
-						b &= $dist[i].cha.hits(f.cha);
-						$dist[i] = f;
+					if let Some(f) = $src.remove($dist[i].urn()) {
+						b = b && $dist[i].cha.hits(f.cha);
+						b = b && $dist[i].urn() == f.urn();
 
+						$dist[i] = f;
 						if $src.is_empty() {
 							break;
 						}
@@ -280,10 +263,9 @@ impl Files {
 		}
 
 		let (mut hidden, mut items) = if let Some(filter) = &self.filter {
-			files.into_iter().partition(|(_, f)| {
-				(f.is_hidden() && !self.show_hidden)
-					|| !f.url.file_name().is_some_and(|s| filter.matches(s))
-			})
+			files
+				.into_iter()
+				.partition(|(_, f)| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.name()))
 		} else if self.show_hidden {
 			(HashMap::new(), files)
 		} else {
@@ -299,11 +281,15 @@ impl Files {
 		(hidden, items)
 	}
 
-	pub fn update_upserting(&mut self, files: HashMap<Url, File>) {
+	pub fn update_upserting(&mut self, files: HashMap<UrnBuf, File>) {
 		if files.is_empty() {
 			return;
 		}
 
+		self.update_deleting(
+			files.iter().filter(|&(u, f)| u != f.urn()).map(|(_, f)| f.urn_owned()).collect(),
+		);
+
 		let (hidden, items) = self.update_updating(files);
 		if hidden.is_empty() && items.is_empty() {
 			return;
@@ -330,10 +316,9 @@ impl Files {
 
 	fn split_files(&self, files: impl IntoIterator<Item = File>) -> (Vec<File>, Vec<File>) {
 		if let Some(filter) = &self.filter {
-			files.into_iter().partition(|f| {
-				(f.is_hidden() && !self.show_hidden)
-					|| !f.url.file_name().is_some_and(|s| filter.matches(s))
-			})
+			files
+				.into_iter()
+				.partition(|f| (f.is_hidden() && !self.show_hidden) || !filter.matches(f.name()))
 		} else if self.show_hidden {
 			(vec![], files.into_iter().collect())
 		} else {
@@ -345,11 +330,11 @@ impl Files {
 impl Files {
 	// --- Items
 	#[inline]
-	pub fn position(&self, url: &Url) -> Option<usize> { self.iter().position(|f| f.url == *url) }
+	pub fn position(&self, urn: &Urn) -> Option<usize> { self.iter().position(|f| urn == f.urn()) }
 
 	// --- Ticket
 	#[inline]
-	pub fn ticket(&self) -> u64 { self.ticket }
+	pub fn ticket(&self) -> Id { self.ticket }
 
 	// --- Sorter
 	#[inline]
