@@ -1,7 +1,8 @@
 use std::{cmp::Ordering, collections::HashMap, mem};
 
-use yazi_config::manager::SortBy;
-use yazi_shared::{fs::{File, Url}, natsort, LcgRng, Transliterator};
+use yazi_shared::{LcgRng, natsort, translit::Transliterator, url::UrnBuf};
+
+use crate::{File, SortBy};
 
 #[derive(Clone, Copy, Default, PartialEq)]
 pub struct FilesSorter {
@@ -13,40 +14,40 @@ pub struct FilesSorter {
 }
 
 impl FilesSorter {
-	pub(super) fn sort(&self, items: &mut Vec<File>, sizes: &HashMap<Url, u64>) {
+	pub(super) fn sort(&self, items: &mut Vec<File>, sizes: &HashMap<UrnBuf, u64>) {
 		if items.is_empty() {
 			return;
 		}
 
 		let by_alphabetical = |a: &File, b: &File| {
 			if self.sensitive {
-				return self.cmp(&*a.url, &*b.url, self.promote(a, b));
+				self.cmp(a.name(), b.name(), self.promote(a, b))
+			} else {
+				self.cmp_insensitive(
+					a.name().as_encoded_bytes(),
+					b.name().as_encoded_bytes(),
+					self.promote(a, b),
+				)
 			}
-
-			self.cmp(
-				a.url.as_os_str().to_ascii_uppercase(),
-				b.url.as_os_str().to_ascii_uppercase(),
-				self.promote(a, b),
-			)
 		};
 
 		match self.by {
 			SortBy::None => {}
-			SortBy::Modified => items.sort_unstable_by(|a, b| {
+			SortBy::Mtime => items.sort_unstable_by(|a, b| {
 				let ord = self.cmp(a.mtime, b.mtime, self.promote(a, b));
 				if ord == Ordering::Equal { by_alphabetical(a, b) } else { ord }
 			}),
-			SortBy::Created => items.sort_unstable_by(|a, b| {
-				let ord = self.cmp(a.ctime, b.ctime, self.promote(a, b));
+			SortBy::Btime => items.sort_unstable_by(|a, b| {
+				let ord = self.cmp(a.btime, b.btime, self.promote(a, b));
 				if ord == Ordering::Equal { by_alphabetical(a, b) } else { ord }
 			}),
 			SortBy::Extension => items.sort_unstable_by(|a, b| {
 				let ord = if self.sensitive {
 					self.cmp(a.url.extension(), b.url.extension(), self.promote(a, b))
 				} else {
-					self.cmp(
-						a.url.extension().map(|s| s.to_ascii_lowercase()),
-						b.url.extension().map(|s| s.to_ascii_lowercase()),
+					self.cmp_insensitive(
+						a.url.extension().map_or(&[], |s| s.as_encoded_bytes()),
+						b.url.extension().map_or(&[], |s| s.as_encoded_bytes()),
 						self.promote(a, b),
 					)
 				};
@@ -55,8 +56,8 @@ impl FilesSorter {
 			SortBy::Alphabetical => items.sort_unstable_by(by_alphabetical),
 			SortBy::Natural => self.sort_naturally(items),
 			SortBy::Size => items.sort_unstable_by(|a, b| {
-				let aa = if a.is_dir() { sizes.get(&a.url).copied() } else { None };
-				let bb = if b.is_dir() { sizes.get(&b.url).copied() } else { None };
+				let aa = if a.is_dir() { sizes.get(a.urn()).copied() } else { None };
+				let bb = if b.is_dir() { sizes.get(b.urn()).copied() } else { None };
 				let ord = self.cmp(aa.unwrap_or(a.len), bb.unwrap_or(b.len), self.promote(a, b));
 				if ord == Ordering::Equal { by_alphabetical(a, b) } else { ord }
 			}),
@@ -79,16 +80,12 @@ impl FilesSorter {
 
 			let ordering = if self.translit {
 				natsort(
-					a.url.as_os_str().as_encoded_bytes().transliterate().as_bytes(),
-					b.url.as_os_str().as_encoded_bytes().transliterate().as_bytes(),
+					a.name().as_encoded_bytes().transliterate().as_bytes(),
+					b.name().as_encoded_bytes().transliterate().as_bytes(),
 					!self.sensitive,
 				)
 			} else {
-				natsort(
-					a.url.as_os_str().as_encoded_bytes(),
-					b.url.as_os_str().as_encoded_bytes(),
-					!self.sensitive,
-				)
+				natsort(a.name().as_encoded_bytes(), b.name().as_encoded_bytes(), !self.sensitive)
 			};
 
 			if self.reverse { ordering.reverse() } else { ordering }
@@ -107,6 +104,25 @@ impl FilesSorter {
 		}
 	}
 
+	#[inline(always)]
+	fn cmp_insensitive(&self, a: &[u8], b: &[u8], promote: Ordering) -> Ordering {
+		if promote != Ordering::Equal {
+			return promote;
+		}
+
+		let l = a.len().min(b.len());
+		let (lhs, rhs) = if self.reverse { (&b[..l], &a[..l]) } else { (&a[..l], &b[..l]) };
+
+		for i in 0..l {
+			match lhs[i].to_ascii_lowercase().cmp(&rhs[i].to_ascii_lowercase()) {
+				Ordering::Equal => (),
+				not_eq => return not_eq,
+			}
+		}
+
+		if self.reverse { b.len().cmp(&a.len()) } else { a.len().cmp(&b.len()) }
+	}
+
 	#[inline(always)]
 	fn promote(&self, a: &File, b: &File) -> Ordering {
 		if self.dir_first { b.is_dir().cmp(&a.is_dir()) } else { Ordering::Equal }
