@@ -10,19 +10,20 @@ function Parent:new(area, tab)
 	}, { __index = self })
 end
 
-function Parent:render()
+function Parent:reflow() return { self } end
+
+function Parent:redraw()
 	if not self._folder then
 		return {}
 	end
 
-	local items = {}
+	local entities = {}
 	for _, f in ipairs(self._folder.window) do
-		local entity = Entity:new(f)
-		items[#items + 1] = ui.ListItem(entity:render()):style(entity:style())
+		entities[#entities + 1] = Entity:new(f):redraw()
 	end
 
 	return {
-		ui.List(self._area, items),
+		ui.List(entities):area(self._area),
 	}
 end
 
