@@ -10,12 +10,12 @@ local function entry()
 		Command("fzf"):cwd(cwd):stdin(Command.INHERIT):stdout(Command.PIPED):stderr(Command.INHERIT):spawn()
 
 	if not child then
-		return fail("Spawn `fzf` failed with error code %s. Do you have it installed?", err)
+		return fail("Failed to start `fzf`, error: " .. err)
 	end
 
 	local output, err = child:wait_with_output()
 	if not output then
-		return fail("Cannot read `fzf` output, error code %s", err)
+		return fail("Cannot read `fzf` output, error: " .. err)
 	elseif not output.status.success and output.status.code ~= 130 then
 		return fail("`fzf` exited with error code %s", output.status.code)
 	end
