@@ -16,6 +16,7 @@ impl Clipboard {
 		use std::os::unix::prelude::OsStringExt;
 
 		use tokio::process::Command;
+		use yazi_fs::CWD;
 		use yazi_shared::in_ssh_connection;
 
 		if in_ssh_connection() {
@@ -30,7 +31,13 @@ impl Clipboard {
 		];
 
 		for (bin, args) in all {
-			let Ok(output) = Command::new(bin).args(args).kill_on_drop(true).output().await else {
+			let Ok(output) = Command::new(bin)
+				.args(args)
+				.current_dir(CWD.load().as_ref())
+				.kill_on_drop(true)
+				.output()
+				.await
+			else {
 				continue;
 			};
 			if output.status.success() {
@@ -54,10 +61,11 @@ impl Clipboard {
 
 	#[cfg(unix)]
 	pub async fn set(&self, s: impl AsRef<std::ffi::OsStr>) {
-		use std::{io::{stderr, BufWriter}, process::Stdio};
+		use std::{io::{BufWriter, stderr}, process::Stdio};
 
 		use crossterm::execute;
 		use tokio::{io::AsyncWriteExt, process::Command};
+		use yazi_fs::CWD;
 
 		s.as_ref().clone_into(&mut self.content.lock());
 		execute!(BufWriter::new(stderr()), osc52::SetClipboard::new(s.as_ref())).ok();
@@ -72,6 +80,7 @@ impl Clipboard {
 		for (bin, args) in all {
 			let cmd = Command::new(bin)
 				.args(args)
+				.current_dir(CWD.load().as_ref())
 				.stdin(Stdio::piped())
 				.stdout(Stdio::null())
 				.stderr(Stdio::null())
@@ -109,7 +118,7 @@ impl Clipboard {
 mod osc52 {
 	use std::ffi::OsStr;
 
-	use base64::{engine::general_purpose, Engine};
+	use base64::{Engine, engine::general_purpose};
 
 	#[derive(Debug)]
 	pub struct SetClipboard {
