@@ -1,11 +1,11 @@
-use std::time::Duration;
+use std::{ops::DerefMut, time::Duration};
 
 use futures::future::try_join3;
 use mlua::{AnyUserData, ExternalError, IntoLua, IntoLuaMulti, Table, UserData, Value};
 use tokio::{io::{self, AsyncBufReadExt, AsyncReadExt, AsyncWriteExt, BufReader, BufWriter}, process::{ChildStderr, ChildStdin, ChildStdout}, select};
 
 use super::Status;
-use crate::process::Output;
+use crate::{Error, process::Output};
 
 pub struct Child {
 	inner:  tokio::process::Child,
@@ -24,27 +24,25 @@ impl Child {
 }
 
 impl UserData for Child {
-	fn add_methods<'lua, M: mlua::UserDataMethods<'lua, Self>>(methods: &mut M) {
+	fn add_methods<M: mlua::UserDataMethods<Self>>(methods: &mut M) {
 		#[inline]
-		// TODO: return mlua::String instead of String
-		async fn read_line(me: &mut Child) -> (String, u8) {
-			async fn read(r: Option<impl AsyncBufReadExt + Unpin>) -> Option<String> {
-				let mut r = r?;
-				let mut buf = String::new();
-				match r.read_line(&mut buf).await {
+		async fn read_line(me: &mut Child) -> (Option<Vec<u8>>, u8) {
+			async fn read(r: Option<impl AsyncBufReadExt + Unpin>) -> Option<Vec<u8>> {
+				let mut buf = Vec::new();
+				match r?.read_until(b'\n', &mut buf).await {
 					Ok(0) | Err(_) => None,
 					Ok(_) => Some(buf),
 				}
 			}
 
 			select! {
-				Some(r) = read(me.stdout.as_mut()) => (r, 0u8),
-				Some(r) = read(me.stderr.as_mut()) => (r, 1u8),
-				else => (String::new(), 2u8),
+				r @ Some(_) = read(me.stdout.as_mut()) => (r, 0u8),
+				r @ Some(_) = read(me.stderr.as_mut()) => (r, 1u8),
+				else => (None, 2u8),
 			}
 		}
 
-		methods.add_async_method_mut("read", |_, me, len: usize| async move {
+		methods.add_async_method_mut("read", |_, mut me, len: usize| async move {
 			async fn read(r: Option<impl AsyncBufReadExt + Unpin>, len: usize) -> Option<Vec<u8>> {
 				let mut r = r?;
 				let mut buf = vec![0; len];
@@ -55,45 +53,54 @@ impl UserData for Child {
 				Some(buf)
 			}
 
+			let me = me.deref_mut();
 			Ok(select! {
 				Some(r) = read(me.stdout.as_mut(), len) => (r, 0u8),
 				Some(r) = read(me.stderr.as_mut(), len) => (r, 1u8),
 				else => (vec![], 2u8)
 			})
 		});
-		methods.add_async_method_mut("read_line", |_, me, ()| async move { Ok(read_line(me).await) });
-		methods.add_async_method_mut("read_line_with", |_, me, options: Table| async move {
-			let timeout: u64 = options.raw_get("timeout")?;
-			match tokio::time::timeout(Duration::from_millis(timeout), read_line(me)).await {
-				Ok(value) => Ok(value),
-				Err(_) => Ok((String::new(), 3u8)),
+		methods.add_async_method_mut("read_line", |lua, mut me, ()| async move {
+			match read_line(&mut me).await {
+				(Some(b), event) => (lua.create_string(b)?, event).into_lua_multi(&lua),
+				(None, event) => (Value::Nil, event).into_lua_multi(&lua),
+			}
+		});
+		methods.add_async_method_mut("read_line_with", |lua, mut me, options: Table| async move {
+			let timeout = Duration::from_millis(options.raw_get("timeout")?);
+			let Ok(result) = tokio::time::timeout(timeout, read_line(&mut me)).await else {
+				return (Value::Nil, 3u8).into_lua_multi(&lua);
+			};
+			match result {
+				(Some(b), event) => (lua.create_string(b)?, event).into_lua_multi(&lua),
+				(None, event) => (Value::Nil, event).into_lua_multi(&lua),
 			}
 		});
 
-		methods.add_async_method_mut("write_all", |lua, me, src: mlua::String| async move {
+		methods.add_async_method_mut("write_all", |lua, mut me, src: mlua::String| async move {
 			let Some(stdin) = &mut me.stdin else {
 				return Err("stdin is not piped".into_lua_err());
 			};
-			match stdin.write_all(src.as_bytes()).await {
-				Ok(()) => (true, Value::Nil).into_lua_multi(lua),
-				Err(e) => (false, e.raw_os_error()).into_lua_multi(lua),
+			match stdin.write_all(&src.as_bytes()).await {
+				Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+				Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
-		methods.add_async_method_mut("flush", |lua, me, ()| async move {
+		methods.add_async_method_mut("flush", |lua, mut me, ()| async move {
 			let Some(stdin) = &mut me.stdin else {
 				return Err("stdin is not piped".into_lua_err());
 			};
 			match stdin.flush().await {
-				Ok(()) => (true, Value::Nil).into_lua_multi(lua),
-				Err(e) => (false, e.raw_os_error()).into_lua_multi(lua),
+				Ok(()) => (true, Value::Nil).into_lua_multi(&lua),
+				Err(e) => (false, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
 
-		methods.add_async_method_mut("wait", |lua, me, ()| async move {
+		methods.add_async_method_mut("wait", |lua, mut me, ()| async move {
 			drop(me.stdin.take());
 			match me.inner.wait().await {
-				Ok(status) => (Status::new(status), Value::Nil).into_lua_multi(lua),
-				Err(e) => (Value::Nil, e.raw_os_error()).into_lua_multi(lua),
+				Ok(status) => (Status::new(status), Value::Nil).into_lua_multi(&lua),
+				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
 		methods.add_async_function("wait_with_output", |lua, ud: AnyUserData| async move {
@@ -120,14 +127,14 @@ impl UserData for Child {
 			match result {
 				Ok((status, stdout, stderr)) => {
 					(Output::new(std::process::Output { status, stdout, stderr }), Value::Nil)
-						.into_lua_multi(lua)
+						.into_lua_multi(&lua)
 				}
-				Err(e) => (Value::Nil, e.raw_os_error()).into_lua_multi(lua),
+				Err(e) => (Value::Nil, Error::Io(e)).into_lua_multi(&lua),
 			}
 		});
 		methods.add_method_mut("start_kill", |lua, me, ()| match me.inner.start_kill() {
 			Ok(_) => (true, Value::Nil).into_lua_multi(lua),
-			Err(e) => (false, e.raw_os_error()).into_lua_multi(lua),
+			Err(e) => (false, Error::Io(e)).into_lua_multi(lua),
 		});
 
 		methods.add_method_mut("take_stdin", |lua, me, ()| match me.stdin.take() {
