@@ -1,10 +1,10 @@
 #![allow(clippy::module_inception)]
 
-mod url;
+use mlua::Lua;
 
-pub use url::*;
+yazi_macro::mod_flat!(url);
 
-pub fn pour(lua: &mlua::Lua) -> mlua::Result<()> {
+pub fn pour(lua: &Lua) -> mlua::Result<()> {
 	url::Url::register(lua)?;
 	url::Url::install(lua)?;
 
