@@ -1,9 +1,10 @@
 use std::time::Duration;
 
 use tokio::sync::oneshot;
-use yazi_shared::{emit, event::Cmd, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::Cmd};
 
-use crate::options::{NotifyLevel, NotifyOpt};
+use crate::options::{NotifyLevel, NotifyOpt, PluginOpt};
 
 pub struct AppProxy;
 
@@ -27,27 +28,31 @@ impl AppProxy {
 
 	#[inline]
 	pub fn notify_warn(title: &str, content: impl ToString) {
-		emit!(Call(
-			Cmd::new("notify").with_any("option", NotifyOpt {
-				title:   title.to_owned(),
-				content: content.to_string(),
-				level:   NotifyLevel::Warn,
-				timeout: Duration::from_secs(5),
-			}),
-			Layer::App
-		));
+		Self::notify(NotifyOpt {
+			title:   title.to_owned(),
+			content: content.to_string(),
+			level:   NotifyLevel::Warn,
+			timeout: Duration::from_secs(5),
+		});
 	}
 
 	#[inline]
 	pub fn notify_error(title: &str, content: impl ToString) {
-		emit!(Call(
-			Cmd::new("notify").with_any("option", NotifyOpt {
-				title:   title.to_owned(),
-				content: content.to_string(),
-				level:   NotifyLevel::Error,
-				timeout: Duration::from_secs(10),
-			}),
-			Layer::App
-		));
+		Self::notify(NotifyOpt {
+			title:   title.to_owned(),
+			content: content.to_string(),
+			level:   NotifyLevel::Error,
+			timeout: Duration::from_secs(10),
+		});
+	}
+
+	#[inline]
+	pub fn plugin(opt: PluginOpt) {
+		emit!(Call(Cmd::new("plugin").with_any("opt", opt), Layer::App));
+	}
+
+	#[inline]
+	pub fn plugin_do(opt: PluginOpt) {
+		emit!(Call(Cmd::new("plugin_do").with_any("opt", opt), Layer::App));
 	}
 }
