@@ -1,17 +1,23 @@
-use yazi_shared::{emit, event::Cmd, fs::Url, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Id, Layer, event::Cmd, url::Url};
 
 use crate::options::OpenDoOpt;
 
 pub struct ManagerProxy;
 
 impl ManagerProxy {
+	#[inline]
+	pub fn spot(skip: Option<usize>) {
+		emit!(Call(Cmd::new("spot").with_opt("skip", skip), Layer::Manager));
+	}
+
 	#[inline]
 	pub fn peek(force: bool) {
 		emit!(Call(Cmd::new("peek").with_bool("force", force), Layer::Manager));
 	}
 
 	#[inline]
-	pub fn hover(url: Option<Url>, tab: usize) {
+	pub fn hover(url: Option<Url>, tab: Id) {
 		emit!(Call(
 			Cmd::args("hover", &url.map_or_else(Vec::new, |u| vec![u])).with("tab", tab),
 			Layer::Manager
@@ -37,8 +43,8 @@ impl ManagerProxy {
 	}
 
 	#[inline]
-	pub fn update_task(url: &Url) {
-		emit!(Call(Cmd::new("update_task").with_any("url", url.clone()), Layer::Manager));
+	pub fn update_tasks(url: &Url) {
+		emit!(Call(Cmd::new("update_tasks").with_any("urls", vec![url.clone()]), Layer::Manager));
 	}
 
 	#[inline]
