@@ -2,7 +2,8 @@ use std::{borrow::Cow, ffi::OsString};
 
 use tokio::sync::oneshot;
 use yazi_config::open::Opener;
-use yazi_shared::{emit, event::Cmd, fs::Url, Layer};
+use yazi_macro::emit;
+use yazi_shared::{Layer, event::Cmd, url::Url};
 
 use crate::options::{OpenWithOpt, ProcessExecOpt};
 
