@@ -1,9 +1,9 @@
-use std::{collections::VecDeque, ffi::OsString};
+use std::ffi::OsString;
 
 use crossterm::event::{KeyEvent, MouseEvent};
 use tokio::sync::mpsc;
 
-use super::Cmd;
+use super::CmdCow;
 use crate::{Layer, RoCell};
 
 static TX: RoCell<mpsc::UnboundedSender<Event>> = RoCell::new();
@@ -11,8 +11,8 @@ static RX: RoCell<mpsc::UnboundedReceiver<Event>> = RoCell::new();
 
 #[derive(Debug)]
 pub enum Event {
-	Call(Cmd, Layer),
-	Seq(VecDeque<Cmd>, Layer),
+	Call(CmdCow, Layer),
+	Seq(Vec<CmdCow>, Layer),
 	Render,
 	Key(KeyEvent),
 	Mouse(MouseEvent),
@@ -41,19 +41,3 @@ impl Event {
 	#[inline]
 	pub fn emit(self) { TX.send(self).ok(); }
 }
-
-#[macro_export]
-macro_rules! emit {
-	(Quit($opt:expr)) => {
-		$crate::event::Event::Quit($opt).emit();
-	};
-	(Call($cmd:expr, $layer:expr)) => {
-		$crate::event::Event::Call($cmd, $layer).emit();
-	};
-	(Seq($cmds:expr, $layer:expr)) => {
-		$crate::event::Event::Seq($cmds, $layer).emit();
-	};
-	($event:ident) => {
-		$crate::event::Event::$event.emit();
-	};
-}
