@@ -11,6 +11,9 @@ impl<T> RoCell<T> {
 	#[inline]
 	pub const fn new() -> Self { Self(UnsafeCell::new(None)) }
 
+	#[inline]
+	pub const fn new_const(value: T) -> Self { Self(UnsafeCell::new(Some(value))) }
+
 	#[inline]
 	pub fn init(&self, value: T) {
 		debug_assert!(!self.initialized());
@@ -27,12 +30,6 @@ impl<T> RoCell<T> {
 		self.init(f());
 	}
 
-	#[inline]
-	pub fn replace(&self, value: T) -> T {
-		debug_assert!(self.initialized());
-		unsafe { mem::replace(&mut *self.0.get(), Some(value)).unwrap_unchecked() }
-	}
-
 	#[inline]
 	pub fn drop(&self) -> T {
 		debug_assert!(self.initialized());
